@@ -61,7 +61,9 @@ def _get_config(root_path='.', is_console=True, module_name='', split_error_log=
             'class': 'logging.handlers.TimedRotatingFileHandler',
             'filename': _get_file_path(root_path, module_name + '.error'),
             'encoding': 'utf8',
-            'formatter': 'verbose'
+            'formatter': 'verbose',
+            'when': 'midnight',
+            'backupCount': int(config('logging.handler.backup_count', default_value=3))
         }
         handlers = ['error', 'info']
     config_dict['root'] = {
@@ -176,3 +178,7 @@ def _callback_log_message(log_level, msg):
             __log_callback(log_level, msg)
         except Exception as ex:
             pass
+
+def raise_error_exception(message):
+    log_error(message)
+    raise Exception(message)
