@@ -90,7 +90,7 @@ class RabbitmqClient(object):
     def close_conn(self):
         self._rabbit_conn.close()
 
-    def consume_msg(self, callback):
+    def consume_msg(self, callback, auto_ack=False):
         while True:
             try:
                 while not self._connect():
@@ -103,7 +103,7 @@ class RabbitmqClient(object):
                     self._queue = q.method.queue
 
                 self._channel.basic_qos(prefetch_count=1)
-                self._channel.basic_consume(self._queue, callback)
+                self._channel.basic_consume(self._queue, callback, auto_ack=auto_ack)
                 self._channel.start_consuming()
             except Exception as e:
                 log_error('consume {} msg error({})'.format(self._queue, e))
